# package_desafio

Description. 
The package package_desafio is used to:
	- Processamento:
	- Correspondência de histograma
	- Semelhança estrutural
	- Redimensionar imagem
Utilitários:
	- Ler imagem
	- Salvar imagem
	- Imagem plotada
	- Resultado do gráfico
	- Plotar histograma

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_desafio

```bash
pip install package_desafio
```

## Usage

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```

## Author
Leonardo Durante Pereira

## License
[MIT](https://choosealicense.com/licenses/mit/)